0.9.9 API documentation: component_wise.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

component_wise.hpp
Go to the documentation of this file.
1
15 #pragma once
16
17 // Dependencies
18 #include "../detail/setup.hpp"
19 #include "../detail/qualifier.hpp"
20
21 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
22 # ifndef GLM_ENABLE_EXPERIMENTAL
23 # pragma message("GLM: GLM_GTX_component_wise is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
24 # else
25 # pragma message("GLM: GLM_GTX_component_wise extension included")
26 # endif
27 #endif
28
29 namespace glm
30 {
33
37 template<typename floatType, length_t L, typename T, qualifier Q>
38 GLM_FUNC_DECL vec<L, floatType, Q> compNormalize(vec<L, T, Q> const& v);
39
43 template<length_t L, typename T, typename floatType, qualifier Q>
44 GLM_FUNC_DECL vec<L, T, Q> compScale(vec<L, floatType, Q> const& v);
45
48 template<typename genType>
49 GLM_FUNC_DECL typename genType::value_type compAdd(genType const& v);
50
53 template<typename genType>
54 GLM_FUNC_DECL typename genType::value_type compMul(genType const& v);
55
58 template<typename genType>
59 GLM_FUNC_DECL typename genType::value_type compMin(genType const& v);
60
63 template<typename genType>
64 GLM_FUNC_DECL typename genType::value_type compMax(genType const& v);
65
67 }//namespace glm
68
69 #include "component_wise.inl"
glm::compMax
GLM_FUNC_DECL genType::value_type compMax(genType const &v)
Find the maximum value between single vector components.
glm::compMul
GLM_FUNC_DECL genType::value_type compMul(genType const &v)
Multiply all vector components together.
glm::compScale
GLM_FUNC_DECL vec< L, T, Q > compScale(vec< L, floatType, Q > const &v)
Convert a normalized float vector to an integer vector.
glm::compNormalize
GLM_FUNC_DECL vec< L, floatType, Q > compNormalize(vec< L, T, Q > const &v)
Convert an integer vector to a normalized float vector.
glm::compMin
GLM_FUNC_DECL genType::value_type compMin(genType const &v)
Find the minimum value between single vector components.
glm::compAdd
GLM_FUNC_DECL genType::value_type compAdd(genType const &v)
Add all vector components together.
glm
Definition: common.hpp:20